==> kubernetes-model-core-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/CSIPersistentVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CSIPersistentVolumeSourceFluent<A extends CSIPersistentVolumeSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildControllerExpandSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getControllerExpandSecretRef();
  public SecretReference buildControllerExpandSecretRef();
  public A withControllerExpandSecretRef(SecretReference controllerExpandSecretRef);
  public Boolean hasControllerExpandSecretRef();
  public A withNewControllerExpandSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editControllerExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRefLike(SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildControllerPublishSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getControllerPublishSecretRef();
  public SecretReference buildControllerPublishSecretRef();
  public A withControllerPublishSecretRef(SecretReference controllerPublishSecretRef);
  public Boolean hasControllerPublishSecretRef();
  public A withNewControllerPublishSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editControllerPublishSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRefLike(SecretReference item);
  public String getDriver();
  public A withDriver(String driver);
  public Boolean hasDriver();
  public String getFsType();
  public A withFsType(String fsType);
  public Boolean hasFsType();
  
  /**
   * This method has been deprecated, please use method buildNodePublishSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getNodePublishSecretRef();
  public SecretReference buildNodePublishSecretRef();
  public A withNodePublishSecretRef(SecretReference nodePublishSecretRef);
  public Boolean hasNodePublishSecretRef();
  public A withNewNodePublishSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildNodeStageSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getNodeStageSecretRef();
  public SecretReference buildNodeStageSecretRef();
  public A withNodeStageSecretRef(SecretReference nodeStageSecretRef);
  public Boolean hasNodeStageSecretRef();
  public A withNewNodeStageSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editNodeStageSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRefLike(SecretReference item);
  public Boolean getReadOnly();
  public A withReadOnly(Boolean readOnly);
  public Boolean hasReadOnly();
  public A addToVolumeAttributes(String key,String value);
  public A addToVolumeAttributes(Map<String,String> map);
  public A removeFromVolumeAttributes(String key);
  public A removeFromVolumeAttributes(Map<String,String> map);
  public Map<String,String> getVolumeAttributes();
  public <K,V>A withVolumeAttributes(Map<String,String> volumeAttributes);
  public Boolean hasVolumeAttributes();
  public String getVolumeHandle();
  public A withVolumeHandle(String volumeHandle);
  public Boolean hasVolumeHandle();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withReadOnly();
  public interface ControllerExpandSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<N>>{
    public N and();
    public N endControllerExpandSecretRef();
    
  }
  public interface ControllerPublishSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<N>>{
    public N and();
    public N endControllerPublishSecretRef();
    
  }
  public interface NodePublishSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<N>>{
    public N and();
    public N endNodePublishSecretRef();
    
  }
  public interface NodeStageSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<N>>{
    public N and();
    public N endNodeStageSecretRef();
    
  }
  
}

==> kubernetes-model-core-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/CSIPersistentVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CSIPersistentVolumeSourceFluent<A extends CSIPersistentVolumeSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildControllerExpandSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getControllerExpandSecretRef();
  public SecretReference buildControllerExpandSecretRef();
  public A withControllerExpandSecretRef(SecretReference controllerExpandSecretRef);
  public Boolean hasControllerExpandSecretRef();
  public A withNewControllerExpandSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editControllerExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRefLike(SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildControllerPublishSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getControllerPublishSecretRef();
  public SecretReference buildControllerPublishSecretRef();
  public A withControllerPublishSecretRef(SecretReference controllerPublishSecretRef);
  public Boolean hasControllerPublishSecretRef();
  public A withNewControllerPublishSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editControllerPublishSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRef();
  public CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRefLike(SecretReference item);
  public String getDriver();
  public A withDriver(String driver);
  public Boolean hasDriver();
  public String getFsType();
  public A withFsType(String fsType);
  public Boolean hasFsType();
  
  /**
   * This method has been deprecated, please use method buildNodeExpandSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getNodeExpandSecretRef();
  public SecretReference buildNodeExpandSecretRef();
  public A withNodeExpandSecretRef(SecretReference nodeExpandSecretRef);
  public Boolean hasNodeExpandSecretRef();
  public A withNewNodeExpandSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.NodeExpandSecretRefNested<A> withNewNodeExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeExpandSecretRefNested<A> withNewNodeExpandSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.NodeExpandSecretRefNested<A> editNodeExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeExpandSecretRefNested<A> editOrNewNodeExpandSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeExpandSecretRefNested<A> editOrNewNodeExpandSecretRefLike(SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildNodePublishSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getNodePublishSecretRef();
  public SecretReference buildNodePublishSecretRef();
  public A withNodePublishSecretRef(SecretReference nodePublishSecretRef);
  public Boolean hasNodePublishSecretRef();
  public A withNewNodePublishSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
  public CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildNodeStageSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretReference getNodeStageSecretRef();
  public SecretReference buildNodeStageSecretRef();
  public A withNodeStageSecretRef(SecretReference nodeStageSecretRef);
  public Boolean hasNodeStageSecretRef();
  public A withNewNodeStageSecretRef(String name,String namespace);
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRefLike(SecretReference item);
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editNodeStageSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRef();
  public CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRefLike(SecretReference item);
  public Boolean getReadOnly();
  public A withReadOnly(Boolean readOnly);
  public Boolean hasReadOnly();
  public A addToVolumeAttributes(String key,String value);
  public A addToVolumeAttributes(Map<String,String> map);
  public A removeFromVolumeAttributes(String key);
  public A removeFromVolumeAttributes(Map<String,String> map);
  public Map<String,String> getVolumeAttributes();
  public <K,V>A withVolumeAttributes(Map<String,String> volumeAttributes);
  public Boolean hasVolumeAttributes();
  public String getVolumeHandle();
  public A withVolumeHandle(String volumeHandle);
  public Boolean hasVolumeHandle();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withReadOnly();
  public interface ControllerExpandSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<N>>{
    public N and();
    public N endControllerExpandSecretRef();
    
  }
  public interface ControllerPublishSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<N>>{
    public N and();
    public N endControllerPublishSecretRef();
    
  }
  public interface NodeExpandSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.NodeExpandSecretRefNested<N>>{
    public N and();
    public N endNodeExpandSecretRef();
    
  }
  public interface NodePublishSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<N>>{
    public N and();
    public N endNodePublishSecretRef();
    
  }
  public interface NodeStageSecretRefNested<N> extends Nested<N>,SecretReferenceFluent<CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<N>>{
    public N and();
    public N endNodeStageSecretRef();
    
  }
  
}
